@@ -39,6 +39,8 @@ import six
 import shlex
 import operator
 import subprocess
+import math
+from packaging.version import LegacyVersion
 from socket import getfqdn
 from ldapurl import LDAPUrl
 from contextlib import closing
@@ -1075,9 +1077,9 @@ def ds_is_related(relation, *ver):
     if len(ver) > 1:
         for cmp_ver in ver:
             if cmp_ver.startswith(ds_ver[:3]):
-                return ops[relation](ds_ver,cmp_ver)
+                return ops[relation](version.parse(ds_ver),version.parse(cmp_ver))
     else:
-        return ops[relation](ds_ver, ver[0])
+        return ops[relation](LegacyVersion(ds_ver), LegacyVersion(ver[0]))
 
 
 def ds_is_older(*ver):
@@ -1301,3 +1303,14 @@ def display_log_value(attr, value, hide_sensitive=True):
 def display_log_data(data, hide_sensitive=True):
     # Take a dict and mask all the sensitive data
     return {a: display_log_value(a, v, hide_sensitive) for a, v in data.items()}
+
+
+def convert_bytes(bytes):
+    bytes = int(bytes)
+    if bytes == 0:
+        return "0 B"
+    size_name = ["B", "KB", "MB", "GB", "TB", "PB"]
+    i = int(math.floor(math.log(bytes, 1024)))
+    pow = math.pow(1024, i)
+    siz = round(bytes / pow, 2)
+    return "{} {}".format(siz, size_name[i])
